@@ -28,45 +28,45 @@ class Dense:
             self.argmax         = None
 
     # Constructor for model initialization
-    def __init__(self, output_shape, input_shape=784, alpha=0.01, beta=0, weight_initialization="normal", sigma_i=0):
+    def __init__(self, output_shape, input_shape=784, alpha=0.01, beta=0, weight_initialization="normal", sigma=0):
         # Layer dimensions are invariable across networks
         self.I                      = input_shape
         self.J                      = output_shape
         self.alpha                  = gpuarray.to_gpu(np.array(alpha,dtype=np.float64))
         self.beta                   = gpuarray.to_gpu(np.array(beta,dtype=np.float64))
         self.weight_initialization  = weight_initialization
-        self.sigma_i                = gpuarray.to_gpu(np.array(sigma_i,dtype=np.float64))
+        self.sigma                = gpuarray.to_gpu(np.array(sigma,dtype=np.float64))
         self.gpu                    = self.functors()
 
     # Layer constructor
     def build(self,number_of_networks,input_shape,output_shape):
         # Layer dimensions
-        (self.L,self.I,self.J)  = (number_of_networks, input_shape, output_shape)
+        (self.V,self.I,self.J)  = (number_of_networks, input_shape, output_shape)
         # Input
-        self.x          = gpuarray.zeros((self.L,self.I),dtype=np.float64)
+        self.x          = gpuarray.zeros((self.V,self.I),dtype=np.float64)
         # Weights
         if (self.weight_initialization=="uniform"):
-            self.w          = np.random.rand(self.L,self.J,self.I).astype(np.float64) * 2 - 1
-            self.b          = np.random.rand(self.L,self.J).astype(np.float64) * 2 - 1
+            self.w          = np.random.rand(self.V,self.J,self.I).astype(np.float64) * 2 - 1
+            self.b          = np.random.rand(self.V,self.J).astype(np.float64) * 2 - 1
         else:
-            self.w          = np.random.normal(0,math.sqrt(2/self.I),(self.L,self.J,self.I)).astype(np.float64)
-            self.b          = np.random.normal(0,math.sqrt(2/self.I),(self.L,self.J)).astype(np.float64)
-        for l in range(self.L):
-            if (self.sigma_i[l].get() > 0):
-                self.w[l]       = np.random.normal(self.w[l],self.sigma_i[l].get())
-                self.b[l]       = np.random.normal(self.b[l],self.sigma_i[l].get())
+            self.w          = np.random.normal(0,math.sqrt(2/self.I),(self.V,self.J,self.I)).astype(np.float64)
+            self.b          = np.random.normal(0,math.sqrt(2/self.I),(self.V,self.J)).astype(np.float64)
+        for l in range(self.V):
+            if (self.sigma[l].get() > 0):
+                self.w[l]       = np.random.normal(self.w[l],self.sigma[l].get())
+                self.b[l]       = np.random.normal(self.b[l],self.sigma[l].get())
         self.w          = gpuarray.to_gpu(self.w)
         self.b          = gpuarray.to_gpu(self.b)
         np.random.normal()
         # Momentum
-        self.mw        = gpuarray.zeros((self.L,self.J,self.I),dtype=np.float64)
-        self.mb        = gpuarray.zeros((self.L,self.J),dtype=np.float64)
+        self.mw        = gpuarray.zeros((self.V,self.J,self.I),dtype=np.float64)
+        self.mb        = gpuarray.zeros((self.V,self.J),dtype=np.float64)
         # Outputs
-        self.y          = gpuarray.zeros((self.L,self.J),dtype=np.float64)
-        self.z          = gpuarray.zeros((self.L,self.J),dtype=np.float64)
+        self.y          = gpuarray.zeros((self.V,self.J),dtype=np.float64)
+        self.z          = gpuarray.zeros((self.V,self.J),dtype=np.float64)
         # Gradients
-        self.dedz       = gpuarray.zeros((self.L,self.J),dtype=np.float64)
-        self.dzdy       = gpuarray.zeros((self.L,self.J),dtype=np.float64)
+        self.dedz       = gpuarray.zeros((self.V,self.J),dtype=np.float64)
+        self.dzdy       = gpuarray.zeros((self.V,self.J),dtype=np.float64)
         # Next layer attributes
         self.n_J        = self.J
         self.n_w        = self.w
@@ -97,7 +97,7 @@ class Dense:
     # Propagate 
     def propagate(self,iteration=-1):
         self.gpu.propagate.prepared_call(
-            (self.L,self.J,1),
+            (self.V,self.J,1),
             (1,1,1),
             np.int32(self.I), 
             np.int32(iteration),
@@ -111,7 +111,7 @@ class Dense:
     # Backpropagate
     def backpropagate(self,iteration=-1,label=-1):
         self.gpu.backpropagate.prepared_call(
-            (self.L,self.J,1),
+            (self.V,self.J,1),
             (1,1,1), 
             np.int32(iteration),
             np.int32(label),
@@ -135,11 +135,9 @@ class Dense:
     # Find winning neuron
     def argmax(self, label, hits):
         self.gpu.argmax.prepared_call(
-            (self.L,self.J,1),
+            (self.V,self.J,1),
             (1,1,1),
             np.int32(label),
             self.z.gpudata,
             hits.gpudata
-        )
-        
-
+        )
\ No newline at end of file
